TIM: Tonight, on the
Project Runway season 16
-reunion special...
-Wah! -[laughter]
All 16 designers reunite,
clear up some issues...
Why would you bring something
that was against the rules?
-Come on. Things happen.
-...voice their opinions...
I thought it was
completely inhumane.
-It’s called integrity.
-...and settle their disputes
once and for all.
I don’t think
you’re telling the truth.
CLAIRE:
That entire situation for me
-was a blur.
-AMY: You know the truth.
You either tell the truth
or you don’t.
♪ ♪
Welcome to the Project Runway
season 16 reunion special.
-Hi, everyone. How are you?
-DESIGNERS: Good.
-It’s great to see all of you
again. -Hi, Tim. -Same.
Our final five.
And I have to say,
-you all look spectacular.
-Well, thank you.
Of course you would.
-You look great, too, Tim.
-[laughs] Thank you.
I want you all to know something
in all sincerity.
This may be my favorite season
in the history
-of Project Runway.
-KENYA: Tim.
You have such unique
points of view as designers.
You couldn’t be more different
as a group.
-KENYA: Yeah.
-Could you possibly?
One of the things that I love
about this season
is that it’s such a celebration
of diversity.
-Yes. -When we look
at the five of you,
I love celebrating
your differences.
Your differences in backgrounds,
your differences in beliefs,
your differences in
points of view as a designer.
And also, I am so just proud
and delighted that you each
have been who you really are.
So kudos to all of you,
and kudos to Project Runway
for helping lead this discussion
in many, many ways.
-Absolutely.
-Absolutely.
-TIM: So, Kentaro?
-KENTARO: Yes.
You are the winner of season 16.
How do you feel?
Like, I feel humbled
and honored, and...
five of us talented designers,
it could have been anyone
to be the winner.
I mean, I even feel like I want
to share this win
with everybody.
Especially my brother, Brandon.
We kind of helped each other.
How was your
Project Runway experience
-in general?
-Uh, it was wonderful.
I did a lot of things
like I wouldn’t do.
Come up with different ideas,
with different ways
of constructing garments.
A lot of pieces I made,
I’m kind of surprised, like,
oh, I could have done that.
TIM:
Wonderful. Good.
How do you feel
about Kentaro’s win?
-Ayana?
-[chuckling]: Well...
I thought it was gonna be me.
-[laughter]
-I do agree with Kentaro.
It really could have been
any of us.
But at the same time,
I think that you deserve it
just as much as I do.
-So congratulations.
-Thank you.
You know, like, everybody’s
journey is different,
and that was meant
for him to have,
and I’m happy that he has it.
Out of this whole experience,
there’s going to be
something great
for everybody sitting
on this sofa.
-Yes.
-So congrats to you.
And if you do want
to share it, um,
I will gladly take
a small percentage.
I will. Yeah.
-[laughter]
-TIM: Wonderful.
I learned something about you
that I only had
an inkling about,
and that is that you are
apparently quite funny.
Let’s take a look.
-Good morning!
-Good morning.
[laughing]
Yay! Thank you, b*tch.
Oh!
No, because it’s nice
when it oozes out a little bit.
-Yeah. -Don’t be so...
What do you call that?
-a**l.
-And... Yeah.
I am super a**l.
Heidi and Tim said,
"Kentaro, don’t be too a**l."
I want to be stopping a**l
because I don’t like
to be a**l all the time.
Like, good morning, a**l.
-Like, no, I’m not a**l.
-[laughter]
Stop, Samantha.
Are you calling me a**l?
-You make me laugh.
-Aw.
You make me feel a**l.
[laughter]
And, Kentaro, you are a**l.
[laughter]
-I’m proud of it.
-TIM: Good. Own it.
And, Ayana, I have to tell you,
you had a spectacular collection
-at New York Fashion Week.
-Thank you, Tim.
You did.
And your finale dress
was one of
the most beautiful garments
-I have ever seen.
-Thank you.
I want to know
how you’d describe
your experience
on Project Runway.
A lot of growth.
I feel like I made
a lot more friends
than I ever expected.
I thought it would...
we would just kind of
be at each other’s necks
all the time.
But, I mean, we were
really good competition
for each other,
but more than anything,
I feel like
motivation for each other.
For me,
the Project Runway experience
was just kind of learning
that it was
okay for me to stand
in my own power,
it was okay for me
to kind of shine in my own way.
I feel like it kind of set me up
to do something even bigger
than I thought I could.
So I’m really excited
for the future.
You should be.
And, Brandon,
you came here
as a menswear designer.
So, how has the experience
-and the process been for you?
-It’s been really cool.
You know, uh, I’m just happy
that my style
and my aesthetic
translated so well.
Feel like I stayed true
to who I am.
Well, I also happen to know
that a number of the models
had a big crush on you.
-[laughter]
-Were you aware of that?
-AYANA: Like, all of them.
-BRANDON: Uh...
no, no, I... No.
[laughter]
He’s covering his a*s.
TIM: They weren’t trying
to seduce you?
-Mm-hmm. Sure, sure.
-Little, secret, dark corners.
BRANDON: I mean, they were...
they were nice.
They-they had some nice words,
and they...
yeah, they were sweet.
Good morning. How are you?
MARSHA:
I was so happy to find out
that Brandon is my designer,
actually.
All the girls are kind of like
in love with him, so...
[laughs]
Brandon’s a sweetheart.
Everybody wants Brandon.
I want to have his child.
It’s gonna be lit. I promise.
The models have a lot
of personality, and...
-I’ll take any of them.
-CHRISTINA: I love Brandon.
but he does have a girlfriend,
so FYI.
[laughter]
TIM:
All right.
Margarita.
You had a knockout of a show.
-Thank you.
-It was simply
over the top and, I thought,
spectacular also.
-Thank you very much.
-And...
you had probably
one of the most memorable
runway moments
when Jazzmine
took off the skirt, and...
-[cheering and applause]
-there she was, curves and all.
-Fab!
-See? I had my moment.
[cheering and applause]
That was a fantastic moment.
-I agree.
-And you’ve also had
quite a roller coaster
of a journey here.
-Yes, I have.
-We want to take a look.
-Lovely. Let’s watch.
-[chuckling]
My name is Margarita Alvarez.
I am 30 years old,
from San Juan, Puerto Rico.
Growing up in Puerto Rico
was amazing.
I mean, you’re on
a beautiful island.
MAN: It sounds like you
maybe begrudgingly
-made the move
to the United States. -Yeah.
I saw what was happening
with Puerto Rico,
and it’s really bad. Like...
the economy’s terrible.
I had a design company
back in Puerto Rico
that I had to close down.
And my parents,
they’re like, "Get out."
[sniffles]
They’re like,
"If you want to be successful
in your field,
you have to leave."
And I was like, "You’re right."
Whew. Mama.
-I kind of want to add
a little Margarita. -[laughs]
♪ ♪
Margarita, you are the winner
of this challenge.
Congratulations.
Thank you so much.
I’m sorry. You’re out.
Thank you for all your support.
TIM:
Wait a minute.
You’re not going anywhere.
I’m using my Tim Gunn save.
Yay!
-[laughing]
-Thank you so much. Thank you.
TIM:
Margarita, when you reflect
upon your Project Runway
experience,
what would you say you learned?
I’m really happy that I got
the chance to self-reflect,
and now I’m here, and I feel
like I’m stronger than ever.
And I’m proud that you
were the Tim Gunn save.
I’m so thankful again.
That was such a special moment.
-I will never forget it.
-I won’t, either.
We’re going to take a break.
When we come back, we’ll have
some of the stars of the season.
Coming up on the season 16
reunion special...
[whooping and applause]
Bring out the lusciousness.
-That’s awesome.
-Oh, God, Kenya.
What was going
through your head at the time?
I think I was just in shock.
Welcome back
to the Project Runway
season 16 reunion special.
Well, as you know,
the five of you
were given the opportunity
to create collections
for New York Fashion Week,
and the judges had
a very difficult time
deciding who shouldn’t show.
HEIDI:
Kenya...
I’m so sorry. You’re out.
Oh, God, Kenya.
I’m reliving it.
What was going through your head
at the time?
I think I was in, like...
like, a freeze-frame.
It wasn’t, uh, registering,
I don’t think.
I really felt like I was going.
I really felt like...
I deserved to go,
I wanted to go, and...
when I found out
I wasn’t gonna go,
it was more like a heartbreak.
-You know...
-TIM: Well, it felt that way.
I think I was just in shock.
Yeah.
You have a profound future.
There are so many places
you can go with your fashion,
and you will.
Thank you. Thank you.
Now I want to share
that another reason
why I loved the season so much
is because of the diversity
of our models.
-Oh, yeah. -Yes!
-You have models
of every size and shape.
In fact, I brought
a few of them back.
-Oh! -Yes!
-We’re gonna bring them out.
-Bring out the lusciousness.
-Yay! -TIM: Come, ladies.
-Hi, Tim. How are you?
-Hi, Christina. Fabulous.
-Oh, my God.
-Mwah!
-Hello. Hello, hello.
-[kissing]
TIM:
Welcome, ladies.
-[whooping]
-Ladies, welcome.
I have to tell you something.
Just by virtue of the fact
that you’re here
says so much about
your importance this season.
It’s been absolutely
extraordinary.
Liris, how was your experience?
I hope that we did help
to expand the thinking
of the general public,
as well as the future designers
who are coming up.
TIM:
Most definitely.
JAZZMINE:
I’m happy that I’m able
to be an advocate
for curvy women.
-Thank you, Tim, for being
an advocate for us. -Always.
MEISHA:
I’m so thankful.
This is actually probably one of
my first modeling jobs
here in New York.
I got an amazing education
as well.
This was an amazing experience.
I really enjoyed it.
CHRISTINA:
Coming on, I think it was
a huge step
in the right direction,
because I’m sort of
in between sizes.
I don’t get a lot of jobs
because of my big
Brazilian booty, but, like,
it’s not going anywhere, so...
We-we love your big
Brazilian booty.
Thank you. Thank you.
It loves you.
[laughter]
We have loved having models
of all sizes this season.
-Yeah.
-And especially the five of you.
And we’re going to take
a little look.
-Oh, goody.
-Oh! Okay.
Hopefully, we don’t say
anything stupid.
It’s gonna look nice
once I take it all in.
I love Kenya’s vibe.
Yes, baby. There we go.
He took in consideration,
like, my body shape.
It kind of hugs me
in the right place.
I feel good.
I get to have my leg out. Boom.
CHRISTINA: Grab some pizza
and some popcorn,
’cause you’re gonna see
a naked girl on Project Runway.
♪ ♪
HEIDI:
I really think her curves,
everything, it just looks
perfect today.
I feel like, for the first time,
really someone got her
TIM:
That was a lot of fun.
Designers, how was
the experience for you?
Designers should be able
to design for women
of all shapes and sizes,
because that’s real life.
And, Brandon,
how did you grow and evolve?
Well, you know,
before coming on the show,
I had never made
women’s clothes.
When I found out
we were dressing
women of all sizes, I was happy
because it allows me
to diverse my skills,
and ultimately,
at the end of the day,
I want to be the best designer
I can be.
Jazzmine and Liris,
I want you to know
that Nina Garcia
is inviting you to be part
of a digital feature
for Marie Claire.
-[gasping]
-Wow. -Wow.
-Congratulations.
-[cheering]
-Oh, my gosh!
-TIM: So congratulations.
We hope you’ll agree.
Of course!
-Oh, my gosh.
-TIM: Good.
Yeah, that’s awesome.
-[laughter]
-Finally.
We’re going to take a break,
and when we come back,
we’ll be joined
by more designers.
Coming up on the season 16
reunion special...
That was a very dramatic moment.
Completely inhumane.
You know,
it was gonna happen sometime.
Why would you bring something
that was against the rules?
-Amy... -You know, we all
surrendered all our stuff.
TIM:
We’re-we’re gonna go there.
Welcome back
to the Project Runway
season 16 reunion special.
And joining us are Michael, Amy,
Batani, Shawn and Claire.
-And it’s great to see
all of you. -You as well.
And, Michael, you epitomize
Heidi’s catchphrase of--
"One day you’re in,
the next day you’re out."
-You won a challenge.
-Yeah.
And the next challenge,
you were out.
Were you shocked?
I mean... not necessarily,
because it’s the name
of the game.
You know, like,
you’ll get eliminated
if you have the weakest look,
and I’m okay with that
because I left
on a look that I love,
and I left on a strong look.
-Mm-hmm.
-TIM: And, Amy, how was this
experience for you, especially
being a fashion teacher?
Um, it was very humbling
in the sense that I kind of
became the student
as much of a teacher.
But I felt good about that.
’Cause you know what?
I would rather walk off
from my own responsibility
than because there was
a competitive angle
that didn’t feel right to me.
-I know exactly how you feel.
-Yeah.
And I loved having you here.
-Anytime.
-[laughter]
Claire and Shawn, we had never
had relatives on the show.
-That’s true. -Yes.
-Let alone twins.
-Let alone identical twins.
-Correct.
You two left
quite an impression.
-I’m Shawn.
-I’m Claire.
BOTH:
We’re identical twins.
MARGARITA: I’m really loving the
environment in the workroom.
We’re all kind of in the zone.
It’s very Zen.
It’s quiet.
SHAWN [sighing]:
Oh, my God.
-Where is she?
-Hi, guys.
-Hi. Claire, I’m here.
-MARGARITA: Sure enough,
first thing is:
"Claire? Shawnie?"
And it’s back to...
[frantic babbling
and screeching]
-High five!
-Oh, my God!
Aah!
CLAIRE:
Shawnie!
KENYA:
I’m just tired of the twins
running around the workroom
like they lost it.
-Whoo!
-Whoop!
If I can find something in
the pink family, I’ll do that,
but if it’s only blue,
I’ll do blue.
Shawn and Claire get
into this enunciation thing
where they are quite pleased
with what is going on.
I’m pleased... [stammers]
at where I’m at thus far.
-[laughter]
-I think there’s something
-familial happening.
-Indeed. Indeed.
"Indeed. Indeed."
[Tim chuckles]
TIM:
There was a challenge
when the two of you
were actually a team,
-and you ended up being
the losing team. -Yes.
That was a very dramatic moment.
HEIDI: We truly don’t know
who’s more responsible
for what look, and who did what.
You will be going head-to-head
in a one-hour challenge.
I just have to do something.
[frustrated grunt]
It’s not the point of it
being pretty, babe.
I just don’t want
to do it, babe.
I just don’t want to.
I know.
SHAWN:
Where’s Tim?
I think it’s Claire
that needs to stay.
Come on, babe.
You know I love you so much.
You’ll make beautiful things
without me, okay?
CLAIRE:
It’s very, very,
very hard.
Claire is here for a reason,
and she needs to continue,
and-and I need to concede.
I mean, I know you guys
obviously work together,
and I understand
that it was, like,
really difficult
to have to be...
-compete against each other.
-Yeah.
But did it come
as a shock to you
that the judges would want
to know who can create what?
No, I don’t think so.
I suppose, you know,
when you’re in the moment,
it was kind of... not attack,
by any means, but just the...
-The onslaught of emotion
-...the onslaught of emotion
that became a barrier.
How did the rest of you feel
about the judges’ decision
to have Claire
and Shawn face off?
I agreed with it.
I was kind of looking forward
to one of you leaving,
because...
I wanted to see individually
what you were made of.
I disagree. I thought it
was completely inhumane.
TIM:
So, speaking for the judges,
I believe they did
the right thing.
I will always
fall on the sword for Claire.
For the rest of you,
were Shawn and Claire
a distraction in the workroom?
We all know that to be true,
but, I mean, point of order
right now--
you both walked
into this competition
breaking the rules and knowing
you were breaking the rules.
Wait, by helping
one another, Amy?
No, by bringing
a stupid tape measure.
I mean, it was just a stupid
tape measure, but why would you
bring something
that was against the rules?
-Amy... -We all surrendered
all our stuff.
-We’re-we’re gonna go there.
-Feels very petty at that point.
-Whatever we’re watching seems
petty. -TIM: Let’s switch gears
for a minute and move on
to another relationship.
Okay. [chuckles]
-Brandon and Kentaro. [chuckles]
-Brother!
-Brother! -You developed quite
a brotherhood, did you not?
BRANDON:
Yeah, we did. We definitely did.
TIM: Yeah, you became
fast friends quickly.
Yeah. No, for sure.
-Let’s take a look.
-Okay.
-Hey, brother.
-Yeah, buddy?
-Good, yeah?
-Yeah.
The bro thing is going down.
Me and my brother,
Kentaro, K Dawg!
I love that Brandon and Kentaro
are brothers.
[laughing]
SHAWN:
Kentaro and Brandon have
such a funny kind
of relationship.
They have, like,
a bromance of sorts.
I’m gonna do twisted sleeve
like this
-and a... like, crop top
like this. -Like this!
Brother, open.
-Brother?
-Yeah, brother.
Brother, what do you think
about this one?
-I like the other one.
-KENYA: They click.
-It makes sense.
-BRANDON: Brother,
-I’m gonna need your eyeball.
-Eyeball.
TIM:
So, what was it that made
the two of you connect so well?
I think it’s the laid-back
cool vibe that they both have.
He’s just super focused,
and he’s good at what he does,
and I was just drawn
towards that.
KENTARO: It’s good to have
someone I can trust.
"Hey, Brandon,
what do you think?"
TIM: Well, you two helped each
other a lot in the workroom.
-Definitely. -You did.
-MICHAEL: Yeah, I find it, like,
weird that we’re kind of
criticizing the twins
for a collaboration
that was innate in them,
and then we’re kind of praising
them for similar instances.
Yeah. It’s a good point.
I see a lot of similarities
between the two sets of us.
It does somewhat dishearten me
that we get a lot of flak
for working together.
AMY: I-I think the difference
just became in...
you guys were quiet. You worked
together very peacefully.
You know, you guys
weren’t so quiet.
You didn’t work together
so peacefully.
So there’s impressions formed
from that.
I suspect
that the two of you wanted
to stay out of the drama,
not create it.
If everyone was so irritated
about me being loud or being...
Why didn’t they say anything?
Why didn’t anyone say anything?
Because, believe me...
b*tch, we did. What the [bleep]
are you talking about?
I said that [bleep] mad times.
We’re going to take a break,
and when we come back,
we’ll have more designers
join us.
Coming up on the season 16
reunion special...
It was what you were wearing.
-Or lack of?
-[laughter]
I don’t feel
that I was able to express
-my side of the story.
-This is your opportunity.
Welcome back to
the Project Runway
season 16 reunion special.
We have all 16 designers here.
-Hi, everyone.
-DESIGNERS: Hi.
Want to welcome Sentell
and Samantha, Aaron, Deyonté,
Kudzanai and ChaCha.
-BOTH: Hey. -TIM: We’re happy
to have you here.
We’re now a full group.
And, Deyonté,
congratulations to you.
-Thank you.
-Since we were last together,
-you have become a father.
-I have.
TIM:
So, how is it
-having a newborn?
-No sleep.
-[laughter]
-But you didn’t have
-any sleep here, either.
-I didn’t, either.
-It was preparing me.
-Exactly. It was... it was
-the rehearsal for the whole
thing. -It’s incredible.
It’s the best.
Just overwhelmed with joy.
-That’s wonderful.
-Really.
Aaron, since the show
has been airing,
do people recognize you?
Yeah. Um, it’s really funny.
I have, like, cute little,
like, people walk up to me
like, "Oh, my God, hey,
what’s up?"
And I’m like, "Oh, my God,
hey, what’s up?"
-[laughter]
-TIM: Well...
while we all were
very enraptured in our own way
with things that you made,
it was what you were wearing...
-Or lack of? -...that was
completely enrapturing
and sometimes a little baffling.
Let’s take a look.
AARON: The beauty of fashion
is there’s no rules anymore.
He’s a dude wearing a dress.
Like, this is crazy.
But for me, it’s just normal.
Aaron is very quirky
and very much
who he is unapologetically,
which brings on
all of his greatness.
[vocalizing upbeat tune]
HEIDI:
What do you think, Zac?
I don’t know. I saw London.
I saw France.
Aaron, thank goodness
-you’re wearing underpants.
-[laughter]
Aaron, we salute your style
and also your bravery.
[chuckling]:
Thank you. Thank you.
All right, we all know
that the biggest controversy
this season
was the cheating scandal.
Claire, congratulations.
You are the winner
of this challenge.
Michael, why are you running
off the stage?
-What happened?
-What is happening?
Michael, what’s wrong?
-What’s wrong?
-I apologize for making a scene.
-No, no, no, wh-what’s wrong?
-I sincerely apologize for that.
What’s wrong?
I honestly don’t know.
All right, so I do believe
in fairness,
and I believe that this win
lacks that.
Somebody tell us
what is going on.
MICHAEL: She has a retractable
ruler in the apartment
that she goes home
and measures her garments
-for proportion, for fit.
-How do we know that?
Well, I am aware of this.
I have seen it,
and we’ve discussed it.
She has mentioned it to me.
Well, we will look into this.
If this is happening,
it must stop.
MARGARITA:
Claire is measuring garments
with a tape measure
that we’re not allowed to have
outside of the workroom.
Bottom line.
That’s what’s wrong here.
I have a tape measure.
Which is explicitly
against the rules.
Fine. Then they can take it.
We cannot have tape measures
or pens or papers.
It’s unfair to the rest of us.
All right, first things first.
-Claire.
-Yes.
Is it true that you have had
a measuring tape in your room?
I have a measuring tape.
Is it true that you’ve been
measuring garments in your room?
I have measured a tank top,
and I have measured
the crotch of a pair of pants.
All right.
Claire, we must rescind your win
and send you home.
Okay.
That’s fine.
That’s fine. That’s fine.
TIM:
Claire’s possession
of the measuring tape
in her hotel room
and the fact that she used it
to measure clothes that she owns
and to make specifications
is what is
against the rules here.
CLAIRE:
That’s...
how my story’s gonna end.
So, I just want to make
very clear here
that the breaking of the rules
was having the measuring tape
at the hotel/apartment.
That is, as Amy said,
expressly against the rules.
CLAIRE:
That entire situation for me
was... was a blur.
I literally felt an... an...
[sighs]
...an onslaught of...
of negativity...
Did she say "negativity"?
...of things that were
coming my way.
It happened so fast, I don’t
feel that I was able to...
-[sighs]
-Articulate?
...articulate
and adequately express
my side of the story.
This is your opportunity.
What is your side of the story?
I was being accused
of having the measuring tape
but also of knocking off
all of my designs.
-Yes. Using the measuring tape.
-CLAIRE: Yes.
I didn’t, uh, initially make
the connection that that’s
-what they were saying.
-AMY: It’s irrelevant.
If a kid hides a textbook
underneath a table
to read it during a test,
they’re still cheating.
-Yeah, really.
-Even if they don’t need it,
which you didn’t need it,
and that’s the
-saddest thing about
all of this. -Hold on.
How many questions
were being thrown at me at once?
You know the truth. You either
tell the truth or you don’t.
It’s not... there-there’s
no confusion in that.
-What I’m saying...
-You seem to be backpedaling
-a little bit now.
-All right, if it’s in...
-No, seriously, though...
-Wait, one minute.
I said, "I’ve got
a measuring tape."
-TIM: Claire.
-Yes.
I’m gonna ask a question.
Did you have a measuring tape
in your apartment/hotel?
Yes. At one time, I had...
-Just... yes. Okay.
-Yes.
And did you use it?
I used...
Just yes or no-- did you use it?
No.
-Wow. -I don’t think
you’re telling the truth.
-Yeah, like, why?
-You made a confession
in the designers’ lounge,
and that’s what I responded to.
You said it yourself. We didn’t
need to go find anything.
You said it.
I answered the question
that I thought that I had heard,
and the question was:
"Did you have a measuring tape?"
And I said yes because,
at one time, yes,
I had brought a measuring tape
home absentmindedly.
You asked if I had taken
-measurements of clothing...
-Please.
...and I had said yes
because I had taken
measurements of clothing--
in the bathroom in the workroom.
-Confused.
-What?!
-No, no, no, what I am...
-I mean, I don’t get it.
-But believe me, at the same...
-Two million people
-just watched what we watched.
-...at the same...
I don’t think there’s
a source of confusion.
What I think was probably
the biggest mistake
was revealing it onstage,
because I felt like
I should have probably
talked to Claire.
I was trying to kind of just
bring it to light
and have it resolved--
what we knew
that she was doing was cheating.
I didn’t want her
to get kicked off.
That was never my intention.
I was stunned, shocked
and completely dismayed
when Michael revealed to me
the true cheating,
which was the measuring tape
and the measuring.
That is egregious cheating,
and there’s nothing gray
about it.
It’s black or it’s white.
I...
-SENTELL: I have a question.
-Yes.
Did you, or did you not
go against the rules?
And if so, do you feel...
do you apologize about that?
’Cause I think this is your
opportunity to kind of like say,
"You know what? I feel sorry.
I apologize.
"It was against the rules,
and-and you know what?
It was bad judgment, and-and it
shouldn’t have been done."
I know that this competition
lends itself to extreme anxiety
and paranoia...
-Such a waste of time.
-This is. -It is. This has
turned to, like,
The Claire and Shawn Show.
They’re never gonna own it,
so let’s just be done with it.
What will be, will be.
And, you know...
-Let it lay.
-Let it lie.
That was a whole lot of nothing.
-Let’s move on, Tim.
-Let’s move on.
All right.
What better way
to turn around from this
and go somewhere positive
than to focus on... Kenya.
-I’ll take that.
-[laughter]
Well, you were a joy
to be around.
-Thank you. -You put a smile
on everyone’s face.
-Thank you.
-And you know how to tailor
the living daylights
out of a suit.
-[laughing]
-Also...
you were quite the songstress.
[laughing]
I want to hear a little bit
about your background.
Well, I’m just a little short
bald-headed girl from Atlanta.
[laughing]
I brought the "A" game,
taken my vitamin C.
I’m not kidding around.
I’m gonna make these dresses,
and I’m coming
to m*rder you guys.
Cool.
-Yeah, very good. Great.
-Yes!
In a nice way.
♪ This super sucks ♪
♪ But Tim would always say,
"Make it work" ♪
[laughter]
♪ Make it work ♪
-♪ Make it work ♪
-KENTARO: ♪ Make it work ♪
♪ Make it work. ♪
That’ll be five dollars.
And how is it going over here?
KENYA:
I don’t know what to do.
I am seriously terrified.
-How are you feeling?
-A little throw-up-ish.
I wouldn’t call myself
an emotional, crazy person.
Yes, I am.
My emotions are really
kind of like
all over the place.
Like, I feel like I need
-my mama to come and give me
-Oh, my gosh.
a hug and, like... [chuckles]
Aw.
[laughing]
-Kenya.
-KENYA: That’s weird.
It is weird to watch me on TV.
I’m like, "Who is that little
round little short little girl?"
[laughter]
We’re gonna take a break,
and we’ll be right back.
Coming up on the season 16
reunion special...
Samantha, you’re very quiet.
You spent two episodes
talking trash about what I made.
-Oh.
-Tell him, Samantha.
Welcome back
to the Project Runway
season 16 reunion special.
Beginning several seasons ago,
there’s been a whole new beat
in the show,
and that is presenting
the designs on the models
who are wearing the top and
bottom looks to the judges.
I call it "up close and
personal" or "touchy-feely."
And in that examination, your
work has very little-- if any--
room for error.
And let’s take a look.
-Oh, gosh.
-Jesus. -No!
-Magic.
-Oh, the buttons.
-The buttons!
-This-- the bottle caps
-as buttons.
-ZAC: I know.
-It’s perfect.
-There’s no back to this.
It’s a tucked-in piece
of fabric.
Oh, that’s so crooked.
-[gasping]
-ZAC: Wow.
[angelic vocalizing]
NINA:
The bows are different colors.
The little detail of the piping.
It’s cool, and it’s today.
It’s not pigeonholed
into a cliché.
[sighing]
I just... I do want
to feel this, though.
Today, when we came in, like, he
didn’t have anything together.
Maybe he panicked.
-Don’t peek, Zac.
-Wait, what? What is...
NINA: How to get the
layered look without the bulk!
-Clever, too.
-TIM: Yeah, it is clever.
Amazing.
So, how do you all feel about
the fact that the judges
have this experience
-with your work?
-I don’t like it.
-You don’t like it, Kenya?
-Only when it’s good.
BRANDON:
No, I think it’s good.
For sure, especially
when you work so hard
to make something,
for them to kind of get up close
and-and really see, you know,
how much effort
you put into the detail.
Well, that and, like,
I feel like
you can always kind of fake it
for a runway, but, like,
when you have
to open it up and see how
-it’s actually constructed...
-It’s another level.
I think that changes everything.
And I have to add
that this season of fashion
was unique, diverse
and, for me, very inspiring.
Everybody’s aesthetic
is different.
TIM:
Exactly. And I have to add
that, in some cases,
the higher you soar,
the further your fall.
-Yeah.
-Mm-hmm.
So let’s take a look at some
of the best and worst looks...
-Oh, Tim!
-...of the season.
Isn’t that for the Internet
to decide?
[laughter]
♪ ♪
ZAC:
It’s exuberant. It’s regal.
HEIDI:
It’s really, really pretty.
Thank you so much.
NINA: The print,
the color, the fluidity
-really captured it for me.
-Thank you.
HEIDI: It is fabulous.
It is different.
Something that we
haven’t seen before.
I think it’s absolutely
beautiful.
HEIDI: Your model today
was the coolest by far
on the runway.
I’m personally a huge fan
of yours, Margarita.
-Thank you so much.
-Like, that is what
I would be running to JCPenney
to get.
I don’t even know
where to begin. I mean...
kind of looks like a scrunchie.
ZAC:
It’s like a clown and a unicorn
had a child.
Looks like you made it
in ten minutes.
Kind of looks
like a piñata that exploded.
It’s too, too, too much.
This is Project Runway,
not Project Kindergarten.
-Be the disco ball. Turn around.
-ZAC: Yeah, do it.
HEIDI: Like a real disco ball.
Keeps going and going.
I mean, it looks so good
from every angle.
It really is fantastic.
I think it’s a showstopper.
HEIDI: I love the bows.
I love the color.
I love the volume.
Surrealist Bo Peep.
-[chuckles]
-Wonderful work. Fun.
This is heaven.
I think this is the chicest
snow woman I have ever seen.
Thank you so much.
The best work
far outweighs the worst.
-Yes.
-And that’s another testament
to this season of the show.
And, Ayana, you won both
-unconventional challenges.
-I did.
As soon as I started
to see stuff, like,
"I could do this with that.
I could do this with that.
I could do..." You guys saw
how much stuff I grabbed.
I think I’m kind of like
a scavenger or something,
but, like...
[laughter]
Well, I have to say, you never
lost sight of who you are,
and you were determined to make
designs for a modest woman,
and you did, but you took it
to entirely new levels.
I think levels that even
exceeded your own expectations.
-For sure.
-We’re gonna take a look.
-Oh!
-[Ayana chuckles]
TIM:
This is your first
unconventional-materials
challenge.
All right, I have to start,
’cause I’m starting
to freak out.
I am a modest designer,
and the only thing
that I’m seeing
is clear plastic,
so you will be able to see
straight through it.
I’m switching it up.
I need to make this work.
NINA: I was particularly
impressed with Ayana.
The drama of the fringe.
There was utter elegance
to this dress.
The buttons in the back,
that was like,
"Oh, there goes my heart
with this dress."
-[laughing]
-Very dramatic
without it having to show
a slice of skin.
She looks so powerful and strong
-and sexy without showing
any skin at all. -Thanks.
Ayana, how do you feel
about showing the world
that you can cover up your body,
yet still be
fashion-forward and chic?
I was a little worried
coming on Project Runway,
because everything has to have
a sleeve, it has to have a pant,
so it’s like,
I have to get more fabric.
But at the same time,
I never wanted the judges
to say that anything
was, like, matronly
or dated or anything like that.
So it was, like, kind of like
a constant struggle.
But I did kind of
do a couple that weren’t
fully modest--
to my standards-- just to
kind of show them a little bit
of flexibility in my skill set.
-I loved it. -So good.
-Just awesome.
BATANI:
And I think, for women,
it’s a lot of pressure on women
to be sexy and show skin,
and I think that what you do,
you show that they can be...
can be sexy and still be covered
and, you know, you’re just
really embracing that
and showing a different
-point of view about it.
-That’s what I love, too.
We’re going to take a break.
We’ll be right back.
Coming up on the season 16
reunion special...
You guys don’t even say it
to us-- how annoying I am!
That’s true. That’s a fact.
-Wah!
-Don’t.
Welcome back. I’m here with
the season 16 designers.
I just want to say that many
of you had quite a lot to say
when no one was watching.
-Uh-oh!
-Let’s take a look.
SAMANTHA: I’ll probably put
a little piece of boning
right there so it’ll stay up
on the side.
CLAIRE: Samantha’s look
kind of looks like poison ivy.
There’s a lot of green
and a lot of texture, and...
it looks kind of like
a hot mess.
MARGARITA: Shawn’s making
a knockoff outfit.
She went to the fabric store
and said,
"Where can I find this lace?
This lace that I’m wearing."
Are you that shameless,
girlfriend?
Hey, Claire,
can I have an opinion?
-Yes. -KENYA: Claire
has to consistently
come to the rescue of Shawn.
Put the pocket bag in.
You have to take ’em apart.
Shawn can’t work
or create anything
if her sister does not help her.
Kenya’s model looks like
Cruella de Vil.
-SANITA: I love it!
-What?!
That [bleep] is just...
KENTARO: Deyonté’s look
is pistachio color.
I like to eat pistachio, but I
don’t like to wear pistachio.
-It’s perfect.
-CLAIRE: Brandon’s look
literally looks like a napkin
tied around his model’s body.
That is...
not even clothing.
That’s a smock
with sleeves
and side boob.
MARGARITA:
Brandon, really?
The pink pinafore
with the topless top?
What?
-Cute?
-Yeah, I love it.
SHAWN:
Kenya’s-- I think it looks
like an oxblood mariachi band.
-I think it’s heinous.
-[Kenya gasps]
So, how do you respond to that?
I feel like the insecurities
speak loud.
That’s all I can say. Just to
say that my look is heinous?
My look wasn’t heinous.
My look was everything.
Okay, how about--
I think, in interviews,
that is the one point
of catharsis.
We are all in
this pressure cooker
of an environment,
and you know we’re not
gonna say it
to each other’s faces,
-so we can say it to...
-Why not, though?
-Because you don’t.
-Because you guys
don’t even say it to us--
how annoying I am.
-Uh...
-Good. That’s good.
-SHAWN: Right?
-Yeah.
-[imitating Shawn]: Aah!
-SHAWN: No, but in
this scenario
that is not real life...
It’s called integrity.
You are who you are.
I don’t go in interviews and say
anything negative, per se,
about anybody in here.
Again with the passive-
aggressiveness, ’cause you
-will easily say... -But that
wasn’t about you, Kenya.
"Oh, good luck. This..."
Whatever, but clearly,
in interviews, you... I mean,
you’re just having a good time.
-Well, so were you when...
-Wah!
But that’s true. That’s a fact.
It-it...
But that’s your opinion.
KENYA:
That wasn’t opinion.
-That’s facts.
-TIM: Samantha...
you’re very quiet.
-Yeah.
-How are you feeling about this?
Because she’s angry because they
talk so much trash about her.
-Tell ’em, Samantha.
-Yeah, I never said a single
bad word about you guys
in interview-- not one--
and you spent two episodes
talking trash about what I made,
and I guess I’m just
a little hurt.
No, no, and-and I apologize,
Samantha.
If any of my actions
caused you pain,
which I understand
that they did,
I greatly apologize for that,
-because that’s not deserved.
-Thank you.
TIM:
All right, designers.
-Who was the toughest
guest judge? -Carly.
The wrist thing-- what is that?
It looks like a phone charger.
Now I can’t stop looking at it.
Like an umbilical cord.
[laughs]
To be very blunt,
it just feels basic.
It-it’s very hooker-ish.
Like, tacky and cheap.
I hate it. [laughs]
She was ruthless.
-Carly would like hearing that,
probably. -Yeah.
-I would say Demi Lovato.
-Demi Lovato?
I was shocked.
I really dislike the shorts.
I don’t feel like, if I put that
on, I would feel sexy in it.
The elastic band is, like,
driving me crazy.
I wish that it was a bit more
practical and flattering.
There are 16 of you
sitting here.
Who is the most underestimated
designer this season?
-Underestimated or...?
-Amy.
-Amy.
-Mm-hmm.
-Thanks, guys.
-[laughter]
I felt like there
were so many challenges
that we all thought Amy
was gonna be on top.
KUDZANAI: I thought the first
one she won, ’cause she...
it was like a show.
She put on a show.
AYANA:
The dance one, too.
Just to watch Amy drape,
I was like,
"Oh, gosh, could you teach me?"
-KENYA: She’s genius. -BRANDON:
I want to say Kudzanai.
I think your style
is super dope, bro, and I think
that, like, what you do
and your techniques, it just...
it takes a lot of time to, like,
do all the, like, mending
and meshing of fabrication,
and... and so it...
yeah, it’s kind of hard to shine
on this stage
with such a short time given.
-I appreciate it. Thank you.
-KENYA: I agree.
You have to see it up close
to appreciate it,
and I’m definitely a fan.
So, the producers put together
a little clip
that they’re calling "Tim-isms."
And I haven’t seen it.
Let’s take a look--
apprehensively.
Designers, rise and shine.
I have breakfast sandwiches
for everyone.
Let me see you move those hips.
Shake your little booty.
Getting dancing lessons
from Heidi Klum.
[both whooping]
-♪ ♪
-[laughter]
They’re... Aah!
Hello, Swatch. We’re back.
[blows whistle]
-[barking] -This outfit
was everything, Tim.
Swatch says time’s up.
Happy birthday to Swatch.
Good-bye, Swatch.
He’s like a baked potato.
[snoring]
Do you think I should put this,
like, over here?
Tim just like this.
[laughter]
This is very shiny.
This takes you...
-Whoo!
-...right into another country.
You have to clear customs.
-Thank you, Tim.
-Make it work!
KENTARO:
I love you.
[chuckles]
All right, before we go,
is there anything
that anyone wants to say
or resolve
or get off their chest?
I’m actually very grateful
to have met everybody here,
and it didn’t hit me
until when I got home
how much of a positive thing
working around so many,
um, creative
and talented people was.
It was just
an amazing experience.
-TIM: You buoy each other up.
-Yeah.
And so often,
I feel that I may be
the only force in the room
that’s doing that,
and I had great partners
in all that this season.
So I thank you for a really
extraordinary experience.
And this is going
to be tough to beat.
We can all come back next time.
-Yeah!
-[laughter]
To all of our loyal fans,
thank you
for watching
season after season.
We love you. Mm.
TIM:
Up we go.
-Oh...
-[chuckling]
[indistinct chatter]
Hey.
HEIDI: Visit myLifetime.com
to learn more
about the fashion you’ve seen
on tonight’s show.
Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
16x16 - Reunion Special
Watch/Buy Amazon
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.